X-Git-Url: https://git.rapsys.eu/airbundle/blobdiff_plain/c7d7cb5720cec3759e68a758f5246e439ff6eb6f..7e8ef252c23703363c351b23ff1d1ce9fac80ce5:/RapsysAirBundle.php

diff --git a/RapsysAirBundle.php b/RapsysAirBundle.php
index b105d39..6096959 100644
--- a/RapsysAirBundle.php
+++ b/RapsysAirBundle.php
@@ -11,16 +11,27 @@
 
 namespace Rapsys\AirBundle;
 
-use Symfony\Component\DependencyInjection\Container;
+use Symfony\Component\DependencyInjection\Extension\ExtensionInterface;
 use Symfony\Component\HttpKernel\Bundle\Bundle;
 
-class RapsysAirBundle extends Bundle{
+/**
+ * {@inheritdoc}
+ */
+class RapsysAirBundle extends Bundle {
+	/**
+	 * {@inheritdoc}
+	 */
+	public function getContainerExtension(): ?ExtensionInterface {
+		//Return created container extension
+		return $this->createContainerExtension();
+	}
+
 	/**
 	 * Return bundle alias
 	 *
 	 * @return string The bundle alias
 	 */
-    public static function getAlias(): string {
+	public static function getAlias(): string {
 		//With namespace
 		if ($npos = strrpos(static::class, '\\')) {
 			//Set name pos
@@ -40,7 +51,17 @@ class RapsysAirBundle extends Bundle{
 			$bpos = strlen(static::class) - $npos;
 		}
 
-		//Return underscored lowercase bundle alias
-		return Container::underscore(substr(static::class, $npos, $bpos));
-    }
+		//Return lowercase bundle alias
+		return strtolower(substr(static::class, $npos, $bpos));
+	}
+
+	/**
+	 * Return bundle version
+	 *
+	 * @return string The bundle version
+	 */
+	public static function getVersion(): string {
+		//Return version
+		return '0.4.0';
+	}
 }